Learn R Programming

wru (version 0.0-2)

getCensusApi: Census API function.

Description

getCensusApi obtains U.S. Census data via the public API.

Usage

getCensusApi(data_url, key, vars, region)

Arguments

data_url
URL root of the API, including the question mark, e.g., "http://api.census.gov/data/2010/sf1?".
key
A required character object containing user's Census API key, which can be requested here.
vars
A character vector of variables to get, e.g., c("P0050003","P0050004","P0050005", "P0050006"). If there are more than 50 variables, then function will automatically split variables into separate queries.
region
Character object specifying which region to obtain data for. Must contain "for" and possibly "in", e.g., "for=block:1213&in=state:47+county:015+tract:*".

Value

If successful, output will be an object of class data.frame. If unsuccessful, function prints the URL query that caused the error.

Details

This function obtains U.S. Census data via the public API. User can specify the variables and region(s) for which to obtain data.

References

Based on code authored by Nicholas Nagle, which is available here.

Examples

Run this code
## Not run: getCensusApi(data_url = "http://api.census.gov/data/2010/sf1?", key = "...", 
# vars = c("P0050003","P0050004","P0050005", "P0050006"), region = "for=county:*&in=state:34")## End(Not run)

Run the code above in your browser using DataLab