Learn R Programming

wru (version 0.0-2)

names.all: Dataset containing Census Surname List and Spanish Surname Lists.

Description

A dataset containing Census Surname List, which is augmented with Census Spanish Surname List. Variables are as follows:
  • surname
  • p_whi (i.e., Pr(White | Surname)
  • p_bla (i.e., Pr(Black | Surname)
  • p_his (i.e., Pr(Hispanic/Latino | Surname)
  • p_asi (i.e., Pr(Asian | Surname)
  • p_oth (i.e., Pr(Other | Surname)

For any surnames appearing only on Spanish Surname List, Pr(Hispanic/Latino | Surname) = 1, and remaining probabilities are set to zero.

Arguments

Format

A data frame with 157,728 rows and 6 variables.